@@ -9,7 +9,7 @@ class VkontakteGroupUpdateUsersM2M(Task):
         logger = self.get_logger(**kwargs)
         logger.info(u'VK group "%s" users m2m relations updating started' % stat.group)
         try:
-            GroupMigration.objects.update_group_users_m2m(stat)
+            stat.update_users_relations()
             logger.info(u'VK group "%s" users m2m relations succesfully updated' % stat.group)
         except:
             logger.error(u'Unknown error while updating users m2m relations of VK group "%s"' % stat.group)
